@@ -504,7 +504,7 @@ check_unoptimized(const PySTEntryObject* ste) {
     case OPT_BARE_EXEC:
         PyOS_snprintf(buf, sizeof(buf),
                       "unqualified exec is not allowed in function "
-                      "'%.100s' it %s",
+                      "'%.100s' because it %s",
                       PyString_AS_STRING(ste->ste_name), trailer);
         break;
     default:
